﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Threading;

namespace MutexHelpers
{

    

    public static class Settings
    {
        public static Mutex s_Mutex = new Mutex(false, @"Global\MutexSettingsFile");

        /// <summary>
        /// Write to the Settings file
        /// </summary>
        /// <param name="content"></param>
        /// <param name="filepath"></param>
        /// <param name="timeout"></param>
        public static void Write(string content, string filepath, double timeout = 5)
        {
            try
            {
                s_Mutex.WaitOne(TimeSpan.FromSeconds(timeout));

                Utils.CreateFileIfNotExist(filepath);

                using (StreamWriter w = new StreamWriter(filepath, false, Encoding.UTF8))
                {
                    w.Write(content);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("error writing to settings file:" + e.Message);
            }
            finally
            {
                s_Mutex.ReleaseMutex();
            }
        }

        /// <summary>
        /// Read from the SettingsFile
        /// </summary>
        /// <param name="filepath"></param>
        /// <param name="timeout"></param>
        /// <returns></returns>
        public static string Read(string filepath, double timeout = 5)
        {
            try
            {
                s_Mutex.WaitOne(TimeSpan.FromSeconds(timeout));

                Utils.CreateFileIfNotExist(filepath);

                using (StreamReader w = new StreamReader(filepath, Encoding.UTF8))
                {
                    return w.ReadToEnd();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("error reading from the settings file:" + e.Message);
                return "";
            }
            finally
            {
                s_Mutex.ReleaseMutex();
            }
        }

        
    }

}
