﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Threading;

namespace MutexHelpers
{
    public static class WatchFile
    {
        public static Mutex w_Mutex = new Mutex(false, @"Global\MutexWatchFile");

        /// <summary>
        /// Write to the Watchfile
        /// </summary>
        /// <param name="content"></param>
        /// <param name="filepath"></param>
        /// <param name="timeout"></param>
        public static void Write(string content, string filepath, double timeout = 5)
        {
            try
            {
                w_Mutex.WaitOne(TimeSpan.FromSeconds(timeout));

                Utils.CreateFileIfNotExist(filepath);

                using (StreamWriter w = new StreamWriter(filepath, false, Encoding.UTF8))
                {
                    w.Write(content);
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("error writing to watchfile:" + e.Message);
            }
            finally
            {
                w_Mutex.ReleaseMutex();
            }
        }

        /// <summary>
        /// Read from the WatchFile
        /// </summary>
        /// <param name="filepath"></param>
        /// <param name="timeout"></param>
        /// <returns></returns>
        public static string Read(string filepath, double timeout = 5)
        {
            try
            {
                w_Mutex.WaitOne(TimeSpan.FromSeconds(timeout));

                Utils.CreateFileIfNotExist(filepath);

                using (StreamReader w = new StreamReader(filepath, Encoding.UTF8))
                {
                    return w.ReadToEnd();
                }
            }
            catch (Exception e)
            {
                Console.WriteLine("error writing to watchfile:" + e.Message);
                return "";
            }
            finally
            {
                w_Mutex.ReleaseMutex();
            }
        }

    }

}
